@@ -13,11 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
 
 from google.cloud.documentai_v1beta2.types import geometry
-from google.protobuf import timestamp_pb2  # type: ignore
-
 
 __protobuf__ = proto.module(
     package="google.cloud.documentai.v1beta2",
@@ -60,9 +59,14 @@ class BatchProcessDocumentsRequest(proto.Message):
     """
 
     requests = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="ProcessDocumentRequest",
+        proto.MESSAGE,
+        number=1,
+        message="ProcessDocumentRequest",
+    )
+    parent = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    parent = proto.Field(proto.STRING, number=2,)
 
 
 class ProcessDocumentRequest(proto.Message):
@@ -110,21 +114,49 @@ class ProcessDocumentRequest(proto.Message):
             Params.
     """
 
-    parent = proto.Field(proto.STRING, number=9,)
-    input_config = proto.Field(proto.MESSAGE, number=1, message="InputConfig",)
-    output_config = proto.Field(proto.MESSAGE, number=2, message="OutputConfig",)
-    document_type = proto.Field(proto.STRING, number=3,)
+    parent = proto.Field(
+        proto.STRING,
+        number=9,
+    )
+    input_config = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="InputConfig",
+    )
+    output_config = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="OutputConfig",
+    )
+    document_type = proto.Field(
+        proto.STRING,
+        number=3,
+    )
     table_extraction_params = proto.Field(
-        proto.MESSAGE, number=4, message="TableExtractionParams",
+        proto.MESSAGE,
+        number=4,
+        message="TableExtractionParams",
     )
     form_extraction_params = proto.Field(
-        proto.MESSAGE, number=5, message="FormExtractionParams",
+        proto.MESSAGE,
+        number=5,
+        message="FormExtractionParams",
     )
     entity_extraction_params = proto.Field(
-        proto.MESSAGE, number=6, message="EntityExtractionParams",
+        proto.MESSAGE,
+        number=6,
+        message="EntityExtractionParams",
+    )
+    ocr_params = proto.Field(
+        proto.MESSAGE,
+        number=7,
+        message="OcrParams",
+    )
+    automl_params = proto.Field(
+        proto.MESSAGE,
+        number=8,
+        message="AutoMlParams",
     )
-    ocr_params = proto.Field(proto.MESSAGE, number=7, message="OcrParams",)
-    automl_params = proto.Field(proto.MESSAGE, number=8, message="AutoMlParams",)
 
 
 class BatchProcessDocumentsResponse(proto.Message):
@@ -137,7 +169,9 @@ class BatchProcessDocumentsResponse(proto.Message):
     """
 
     responses = proto.RepeatedField(
-        proto.MESSAGE, number=1, message="ProcessDocumentResponse",
+        proto.MESSAGE,
+        number=1,
+        message="ProcessDocumentResponse",
     )
 
 
@@ -155,8 +189,16 @@ class ProcessDocumentResponse(proto.Message):
             objects.
     """
 
-    input_config = proto.Field(proto.MESSAGE, number=1, message="InputConfig",)
-    output_config = proto.Field(proto.MESSAGE, number=2, message="OutputConfig",)
+    input_config = proto.Field(
+        proto.MESSAGE,
+        number=1,
+        message="InputConfig",
+    )
+    output_config = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="OutputConfig",
+    )
 
 
 class OcrParams(proto.Message):
@@ -176,7 +218,10 @@ class OcrParams(proto.Message):
             specified languages is not one of the supported languages.
     """
 
-    language_hints = proto.RepeatedField(proto.STRING, number=1,)
+    language_hints = proto.RepeatedField(
+        proto.STRING,
+        number=1,
+    )
 
 
 class TableExtractionParams(proto.Message):
@@ -199,12 +244,23 @@ class TableExtractionParams(proto.Message):
             "builtin/latest" for the latest model.
     """
 
-    enabled = proto.Field(proto.BOOL, number=1,)
+    enabled = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
     table_bound_hints = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="TableBoundHint",
+        proto.MESSAGE,
+        number=2,
+        message="TableBoundHint",
+    )
+    header_hints = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
+    model_version = proto.Field(
+        proto.STRING,
+        number=4,
     )
-    header_hints = proto.RepeatedField(proto.STRING, number=3,)
-    model_version = proto.Field(proto.STRING, number=4,)
 
 
 class TableBoundHint(proto.Message):
@@ -223,8 +279,15 @@ class TableBoundHint(proto.Message):
             axis-aligned rectangle.
     """
 
-    page_number = proto.Field(proto.INT32, number=1,)
-    bounding_box = proto.Field(proto.MESSAGE, number=2, message=geometry.BoundingPoly,)
+    page_number = proto.Field(
+        proto.INT32,
+        number=1,
+    )
+    bounding_box = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=geometry.BoundingPoly,
+    )
 
 
 class FormExtractionParams(proto.Message):
@@ -257,11 +320,19 @@ class FormExtractionParams(proto.Message):
             are stored.
     """
 
-    enabled = proto.Field(proto.BOOL, number=1,)
+    enabled = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
     key_value_pair_hints = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="KeyValuePairHint",
+        proto.MESSAGE,
+        number=2,
+        message="KeyValuePairHint",
+    )
+    model_version = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    model_version = proto.Field(proto.STRING, number=3,)
 
 
 class KeyValuePairHint(proto.Message):
@@ -277,8 +348,14 @@ class KeyValuePairHint(proto.Message):
             Types not in this list will be ignored.
     """
 
-    key = proto.Field(proto.STRING, number=1,)
-    value_types = proto.RepeatedField(proto.STRING, number=2,)
+    key = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    value_types = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
 
 
 class EntityExtractionParams(proto.Message):
@@ -293,8 +370,14 @@ class EntityExtractionParams(proto.Message):
             "builtin/latest" for the latest model.
     """
 
-    enabled = proto.Field(proto.BOOL, number=1,)
-    model_version = proto.Field(proto.STRING, number=2,)
+    enabled = proto.Field(
+        proto.BOOL,
+        number=1,
+    )
+    model_version = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class AutoMlParams(proto.Message):
@@ -308,7 +391,10 @@ class AutoMlParams(proto.Message):
             ``projects/{project-id}/locations/{location-id}/models/{model-id}``.
     """
 
-    model = proto.Field(proto.STRING, number=1,)
+    model = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class InputConfig(proto.Message):
@@ -347,10 +433,20 @@ class InputConfig(proto.Message):
     """
 
     gcs_source = proto.Field(
-        proto.MESSAGE, number=1, oneof="source", message="GcsSource",
+        proto.MESSAGE,
+        number=1,
+        oneof="source",
+        message="GcsSource",
+    )
+    contents = proto.Field(
+        proto.BYTES,
+        number=3,
+        oneof="source",
+    )
+    mime_type = proto.Field(
+        proto.STRING,
+        number=2,
     )
-    contents = proto.Field(proto.BYTES, number=3, oneof="source",)
-    mime_type = proto.Field(proto.STRING, number=2,)
 
 
 class OutputConfig(proto.Message):
@@ -385,9 +481,15 @@ class OutputConfig(proto.Message):
     """
 
     gcs_destination = proto.Field(
-        proto.MESSAGE, number=1, oneof="destination", message="GcsDestination",
+        proto.MESSAGE,
+        number=1,
+        oneof="destination",
+        message="GcsDestination",
+    )
+    pages_per_shard = proto.Field(
+        proto.INT32,
+        number=2,
     )
-    pages_per_shard = proto.Field(proto.INT32, number=2,)
 
 
 class GcsSource(proto.Message):
@@ -399,7 +501,10 @@ class GcsSource(proto.Message):
 
     """
 
-    uri = proto.Field(proto.STRING, number=1,)
+    uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class GcsDestination(proto.Message):
@@ -411,7 +516,10 @@ class GcsDestination(proto.Message):
 
     """
 
-    uri = proto.Field(proto.STRING, number=1,)
+    uri = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class OperationMetadata(proto.Message):
@@ -439,10 +547,25 @@ class OperationMetadata(proto.Message):
         CANCELLED = 5
         FAILED = 6
 
-    state = proto.Field(proto.ENUM, number=1, enum=State,)
-    state_message = proto.Field(proto.STRING, number=2,)
-    create_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
+    state = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=State,
+    )
+    state_message = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
